@@ -280,7 +280,7 @@ class BaseTroveTest(test.BaseTestCase):
 
     @classmethod
     def delete_swift_account(cls):
-        LOG.info(f"Cleaning up Swift account")
+        LOG.info("Cleaning up Swift account")
         try:
             cls.account_client.delete('')
         except exceptions.NotFound:
@@ -481,10 +481,10 @@ class BaseTroveTest(test.BaseTestCase):
                                                             message=message)
                 raise exceptions.UnexpectedResponseCode(message)
 
-        if type(expected_status) != list:
+        if not isinstance(expected_status, list):
             expected_status = [expected_status]
 
-        if type(expected_op_status) != list:
+        if not isinstance(expected_op_status, list):
             expected_op_status = [expected_op_status]
 
         if need_delete:
@@ -550,7 +550,7 @@ class BaseTroveTest(test.BaseTestCase):
 
     @classmethod
     def create_backup(cls, instance_id, backup_name, incremental=False,
-                      parent_id=None, description=None):
+                      parent_id=None, description=None, storage_driver=None):
         body = {
             "backup": {
                 "name": backup_name,
@@ -558,6 +558,8 @@ class BaseTroveTest(test.BaseTestCase):
                 "incremental": 1 if incremental else 0,
             }
         }
+        if storage_driver:
+            body["backup"]["storage_driver"] = storage_driver
         if description:
             body['backup']['description'] = description
         if parent_id:
@@ -602,7 +604,7 @@ class BaseTroveTest(test.BaseTestCase):
                                                             message=message)
                 raise exceptions.UnexpectedResponseCode(message)
 
-        if type(expected_status) != list:
+        if not isinstance(expected_status, list):
             expected_status = [expected_status]
 
         if need_delete:
